@@ -6,8 +6,13 @@ from time import time
 
 import cv2
 
-from maps4fs import Map
+from maps4fs import DTMProvider, Map
 from maps4fs.generator.game import Game
+from maps4fs.generator.settings import (
+    BackgroundSettings,
+    DEMSettings,
+    SatelliteSettings,
+)
 
 working_directory = os.getcwd()
 
@@ -27,6 +32,17 @@ coordinates_cases = [
 
 game_code_cases = ["FS25"]
 
+dtm_provider_code = "srtm30"
+dtm_provider = DTMProvider.get_provider_by_code(dtm_provider_code)
+
+
+background_settings = BackgroundSettings(
+    generate_background=True,
+    generate_water=True,
+    resize_factor=16,
+    remove_center=False,
+)
+
 
 def get_random_size() -> tuple[int, int]:
     """Return random size.
@@ -74,8 +90,13 @@ def test_map():
             height, width = get_random_size()
             directory = map_directory(game_code)
 
+            print(f"Generating map for {game_code} at {coordinates} with size {height}x{width}...")
+
             map = Map(
                 game=game,
+                dtm_provider=dtm_provider,
+                dtm_provider_settings=None,
+                background_settings=background_settings,
                 coordinates=coordinates,
                 size=height,
                 rotation=0,
@@ -136,6 +157,9 @@ def test_map_preview():
     directory = map_directory(game_code)
     map = Map(
         game=game,
+        dtm_provider=dtm_provider,
+        dtm_provider_settings=None,
+        background_settings=background_settings,
         coordinates=case,
         size=height,
         rotation=0,
@@ -161,13 +185,22 @@ def test_map_pack():
 
     height, width = get_random_size()
 
+    dem_settings = DEMSettings(multiplier=2, blur_radius=15, plateau=1000, water_depth=500)
+
+    satellite_settings = SatelliteSettings(download_images=True, satellite_margin=0, zoom_level=14)
+
     directory = map_directory(game_code)
     map = Map(
         game=game,
+        dtm_provider=dtm_provider,
+        dtm_provider_settings=None,
         coordinates=case,
         size=height,
         rotation=30,
         map_directory=directory,
+        dem_settings=dem_settings,
+        background_settings=background_settings,
+        satellite_settings=satellite_settings,
     )
     for _ in map.generate():
         pass
